==> dotnet_runtime-7.0.14.tar.gz: runtime-7.0.14/src/libraries/System.Security.Cryptography/src/System/Security/Cryptography/ChaCha20Poly1305.NotSupported.cs <==
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

using System.Diagnostics;

namespace System.Security.Cryptography
{
    public partial class ChaCha20Poly1305
    {
        public static bool IsSupported => false;

#pragma warning disable CA1822
        private void ImportKey(ReadOnlySpan<byte> key)
        {
            Debug.Fail("Instance ctor should fail before we reach this point.");
            throw new NotImplementedException();
        }

        private void EncryptCore(
            ReadOnlySpan<byte> nonce,
            ReadOnlySpan<byte> plaintext,
            Span<byte> ciphertext,
            Span<byte> tag,
            ReadOnlySpan<byte> associatedData = default)
        {
            Debug.Fail("Instance ctor should fail before we reach this point.");
            throw new NotImplementedException();
        }

        private void DecryptCore(
            ReadOnlySpan<byte> nonce,
            ReadOnlySpan<byte> ciphertext,
            ReadOnlySpan<byte> tag,
            Span<byte> plaintext,
            ReadOnlySpan<byte> associatedData = default)
        {
            Debug.Fail("Instance ctor should fail before we reach this point.");
            throw new NotImplementedException();
        }

        public void Dispose()
        {
            Debug.Fail("Instance ctor should fail before we reach this point.");
            // no-op
        }
#pragma warning restore CA1822
    }
}

==> dotnet_runtime-8.0.7.tar.gz: runtime-8.0.7/src/libraries/System.Security.Cryptography/src/System/Security/Cryptography/ChaCha20Poly1305.NotSupported.cs <==
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

using System.Diagnostics;

namespace System.Security.Cryptography
{
    public partial class ChaCha20Poly1305
    {
        public static bool IsSupported => false;

#pragma warning disable CA1822, IDE0060
        private void ImportKey(ReadOnlySpan<byte> key)
        {
            Debug.Fail("Instance ctor should fail before we reach this point.");
            throw new NotImplementedException();
        }

        private void EncryptCore(
            ReadOnlySpan<byte> nonce,
            ReadOnlySpan<byte> plaintext,
            Span<byte> ciphertext,
            Span<byte> tag,
            ReadOnlySpan<byte> associatedData = default)
        {
            Debug.Fail("Instance ctor should fail before we reach this point.");
            throw new NotImplementedException();
        }

        private void DecryptCore(
            ReadOnlySpan<byte> nonce,
            ReadOnlySpan<byte> ciphertext,
            ReadOnlySpan<byte> tag,
            Span<byte> plaintext,
            ReadOnlySpan<byte> associatedData = default)
        {
            Debug.Fail("Instance ctor should fail before we reach this point.");
            throw new NotImplementedException();
        }

        public void Dispose()
        {
            Debug.Fail("Instance ctor should fail before we reach this point.");
            // no-op
        }
#pragma warning restore CA1822, IDE0060
    }
}
